@@ -535,10 +535,6 @@ void mutt_enter_command (void)
   BUFFER err, token;
   char buffer[LONG_STRING], errbuf[SHORT_STRING];
   int r;
-  int old_strictthreads  = option (OPTSTRICTTHREADS);
-  int old_sortre	 = option (OPTSORTRE);
-  int old_hidemissing	 = option (OPTHIDEMISSING);
-  int old_threadreceived = option (OPTTHREADRECEIVED);
 
   buffer[0] = 0;
   if (mutt_get_field (":", buffer, sizeof (buffer), M_COMMAND) != 0 || !buffer[0])
@@ -558,11 +554,6 @@ void mutt_enter_command (void)
     else
       mutt_error ("%s", errbuf);
   }
-  if (option (OPTSTRICTTHREADS) != old_strictthreads ||
-      option (OPTSORTRE) != old_sortre ||
-      option (OPTHIDEMISSING) != old_hidemissing ||
-      option (OPTTHREADRECEIVED) != old_threadreceived)
-    set_option (OPTNEEDRESORT);
 }
 
 void mutt_display_address (ENVELOPE *env)
@@ -652,10 +643,13 @@ int mutt_save_message (HEADER *h, int delete,
   *redraw = 0;
 
   
-  snprintf (prompt, sizeof (prompt), _("%s%s to mailbox"),
-	    decode ? (delete ? _("Decode-save") : _("Decode-copy")) :
-	    (decrypt ? (delete ? _("Decrypt-save") : _("Decrypt-copy")):
-	     (delete ? _("Save") : _("Copy"))), h ? "" : _(" tagged"));
+  snprintf (prompt, sizeof (prompt),
+	    decode  ? (delete ? _("Decode-save%s to mailbox") :
+		       _("Decode-copy%s to mailbox")) :
+	    (decrypt ? (delete ? _("Decrypt-save%s to mailbox") :
+			_("Decrypt-copy%s to mailbox")) :
+	     (delete ? _("Save%s to mailbox") : _("Copy%s to mailbox"))),
+	    h ? "" : _(" tagged"));
   
   if (h)
   {
